@@ -27,8 +27,6 @@ from .utils import (
 )
 
 
-
-
 class Subtype:
     """
     Subtype model class.
@@ -48,13 +46,13 @@ class Subtype:
 
         # check for valid subtype names in RELATION_SUBTYPES
         if name not in RELATION_SUBTYPES:
-            raise ValueError(f"Name of relation subtype '{name}' is not in list of valid subtypes.")
+            raise ValueError(
+                f"Name of relation subtype '{name}' is not in list of valid subtypes."
+            )
 
         self.name: str = name
         self.value: str = value
 
-
-
     @staticmethod
     def parse(item: Element) -> "Subtype":
         """
@@ -71,10 +69,9 @@ class Subtype:
         # Generate and return subtype instance
         return Subtype(
             name=get_attribute(element=item, key="name"),
-            value=get_attribute(element=item, key="value")
+            value=get_attribute(element=item, key="value"),
         )
 
-
     def to_xml(self) -> Element:
         """
         Generate XML string from Subtype element.
@@ -85,13 +82,9 @@ class Subtype:
 
         return Element(
             "subtype",
-            attrib={
-                "name": self.name,
-                "value": self.value
-            },
+            attrib={"name": self.name, "value": self.value},
         )
 
-
     def __str__(self) -> str:
         """
         Generate string from Subtype instance.
@@ -102,10 +95,6 @@ class Subtype:
         return f"<Subtype name='{self.name}' value='{self.value}'>"
 
 
-
-
-
-
 class Relation:
     """
     Relation model class.
@@ -134,7 +123,6 @@ class Relation:
         self.type: str = type
         self.subtypes: List[Subtype] = []
 
-
     @staticmethod
     def parse(item: Element) -> "Relation":
         """
@@ -148,7 +136,6 @@ class Relation:
         # Check tag of relation is correct
         assert item.tag == "relation"
 
-
         # Create relation instance from attributes
         relation: Relation = Relation(
             entry1=get_numeric_attribute(element=item, key="entry1"),
@@ -156,15 +143,12 @@ class Relation:
             type=get_attribute(element=item, key="type"),
         )
 
-
         # Parse Child items of xml element by iterating of child elements
         for child in item:
             relation.subtypes.append(Subtype.parse(item=child))
 
-
         return relation
 
-
     def to_xml(self) -> Element:
         """
         Generate XML string from Relation element.
@@ -192,8 +176,6 @@ class Relation:
         return f"<Relation {self.entry1}->{self.entry2} type='{self.type}'>"
 
 
-
-
 class Component:
     """
     Component model.
@@ -210,13 +192,11 @@ class Component:
         if id == "":
             raise ValueError("Component id can't be empty.")
 
-
         # TODO: Check pattern of component id
         # TODO: component id should reference an existing entry !
 
         self.id: str = id
 
-
     @staticmethod
     def parse(item: Element) -> "Component":
         """
@@ -233,7 +213,6 @@ class Component:
         # Create component instance from id attribute
         return Component(id=get_attribute(element=item, key="id"))
 
-
     def to_xml(self) -> Element:
         """
         Generate XML string from Component element.
@@ -249,7 +228,6 @@ class Component:
             },
         )
 
-
     def __str__(self) -> str:
         """
         Build string of component instance.
@@ -260,12 +238,13 @@ class Component:
         return f"<Component id='{self.id}'>"
 
 
-
 class Graphics:
     """
     Graphics information for rendering.
     """
 
+    # pylint: disable=too-many-instance-attributes
+
     def __init__(
         self,
         x: Optional[str] = None,
@@ -292,6 +271,8 @@ class Graphics:
         :param typing.Optional[str] bgcolor:
         """
 
+        # pylint: disable=too-many-arguments
+
         # All parameter are implied (optional)
         self.x: Optional[str] = x
         self.y: Optional[str] = y
@@ -303,7 +284,6 @@ class Graphics:
         self.fgcolor: Optional[str] = fgcolor
         self.bgcolor: Optional[str] = bgcolor
 
-
         # Validate parameter if not None
 
         # Check type is in list of valid types
@@ -317,7 +297,6 @@ class Graphics:
         if self.bgcolor is not None and is_valid_hex_color(value=self.bgcolor) is False:
             raise ValueError("Bgcolor is not a valid hex color.")
 
-
         # Check x,y,width and height are numeric (only if not None)
         if self.x is not None and str.isdigit(self.x) is False:
             raise ValueError("Value x is not a number.")
@@ -331,7 +310,6 @@ class Graphics:
         if self.height is not None and str.isdigit(self.height) is False:
             raise ValueError("Value height is not a number.")
 
-
     @staticmethod
     def parse(item: Element) -> "Graphics":
         """
@@ -347,18 +325,17 @@ class Graphics:
 
         # Parse attributes from XML element
         return Graphics(
-            x = item.attrib.get("x"),
-            y = item.attrib.get("y"),
-            width = item.attrib.get("width"),
-            height = item.attrib.get("height"),
-            name = item.attrib.get("name"),
-            type = item.attrib.get("type"),
-            fgcolor = item.attrib.get("fgcolor"),
-            bgcolor = item.attrib.get("bgcolor"),
-            coords = item.attrib.get("coords"),
+            x=item.attrib.get("x"),
+            y=item.attrib.get("y"),
+            width=item.attrib.get("width"),
+            height=item.attrib.get("height"),
+            name=item.attrib.get("name"),
+            type=item.attrib.get("type"),
+            fgcolor=item.attrib.get("fgcolor"),
+            bgcolor=item.attrib.get("bgcolor"),
+            coords=item.attrib.get("coords"),
         )
 
-
     def to_xml(self) -> Element:
         """
         Generate XML string from Graphics element.
@@ -400,7 +377,6 @@ class Graphics:
 
         return graphics_element
 
-
     def __str__(self) -> str:
         """
         Return Graphics instance summary string.
@@ -411,7 +387,6 @@ class Graphics:
         return f"<Graphics name='{self.name}'>"
 
 
-
 class Entry:
     """
     Entry model class.
@@ -435,6 +410,8 @@ class Entry:
         :param typing.Optional[str] reaction: Reaction TODO: specify. Is str format correct?
         """
 
+        # pylint: disable=too-many-arguments
+
         # required
         self.id: str = id
         self.name: str = name
@@ -442,23 +419,19 @@ class Entry:
 
         # TODO: validate entry id and name
 
-
         if self.type not in ENTRY_TYPE:
             raise ValueError(f"Type '{self.type}' is not in list of valid entry types.")
 
-
         # optional (implied)
         self.link: Optional[str] = link
         self.reaction: Optional[str] = reaction
 
         # TODO: validate reaction if not None
 
-
         # Implied child instances
         self.graphics: Optional[Graphics] = None
         self.components: List[Component] = []
 
-
     @property
     def has_multiple_names(self) -> bool:
         """
@@ -470,8 +443,6 @@ class Entry:
 
         return len(self.name.split(" ")) > 1
 
-
-
     @staticmethod
     def parse(item: Element) -> "Entry":
         """
@@ -502,7 +473,6 @@ class Entry:
 
         return entry
 
-
     def to_xml(self) -> Element:
         """
         Generate XML string from Entry element.
@@ -512,12 +482,7 @@ class Entry:
         """
 
         entry_element: Element = Element(
-            "entry",
-            attrib={
-                "id": self.id,
-                "name": self.name,
-                "type": self.type
-            }
+            "entry", attrib={"id": self.id, "name": self.name, "type": self.type}
         )
 
         # Add optional attributes to xml element
@@ -533,17 +498,12 @@ class Entry:
         if self.graphics is not None:
             entry_element.append(self.graphics.to_xml())
 
-
         # Iterate over components and add to entry element
         for component in self.components:
             entry_element.append(component.to_xml())
 
-
         return entry_element
 
-
-
-
     def __str__(self) -> str:
         """
         Build Entry summary string.
@@ -553,8 +513,6 @@ class Entry:
         """
         return f"<Entry id='{self.id}' name='{self.name}' type='{self.type}'>"
 
-
-
     def get_gene_id(self) -> List[str]:
         """
         Parse variable 'name' of Entry into KEGG id.
@@ -570,8 +528,6 @@ class Entry:
         return [value.split(":")[1] for value in self.name.split(" ")]
 
 
-
-
 class Alt:
     """
     Alt model.
@@ -586,7 +542,6 @@ class Alt:
 
         self.name: str = name
 
-
     @staticmethod
     def parse(item: Element) -> "Alt":
         """
@@ -600,7 +555,6 @@ class Alt:
 
         return Alt(name=get_attribute(element=item, key="name"))
 
-
     def to_xml(self) -> Element:
         """
         Generate XML string from Alt element.
@@ -616,7 +570,6 @@ class Alt:
             },
         )
 
-
     def __str__(self) -> str:
         """
         Build string from Alt instance.
@@ -633,12 +586,7 @@ class Product:
     Reaction Product model.
     """
 
-    def __init__(
-        self,
-        id: str,
-        name: str,
-        alt: Optional[Alt] = None
-        ) -> None:
+    def __init__(self, id: str, name: str, alt: Optional[Alt] = None) -> None:
         """
         Init Product instance.
 
@@ -683,7 +631,6 @@ class Product:
 
         return parsed_product
 
-
     def to_xml(self) -> Element:
         """
         Generate XML string from Product element.
@@ -706,7 +653,6 @@ class Product:
 
         return product_element
 
-
     def __str__(self) -> str:
         """
         Build string from Product instance.
@@ -721,12 +667,13 @@ class Substrate:
     """
     reaction Substrate model
     """
+
     def __init__(
         self,
         id: str,
         name: str,
         alt: Optional[Alt] = None,
-        ) -> None:
+    ) -> None:
         """
         Init Substrate instance.
 
@@ -771,7 +718,6 @@ class Substrate:
 
         return parsed_substrate
 
-
     def to_xml(self) -> Element:
         """
         Generate XML string from Substrate element.
@@ -794,7 +740,6 @@ class Substrate:
 
         return substrate_element
 
-
     def __str__(self) -> str:
         """
         Build string from Substrate instance.
@@ -805,7 +750,6 @@ class Substrate:
         return f"<Substrate id='{self.id}' name='{self.name}'>"
 
 
-
 class Reaction:
     """
     Reaction model.
@@ -816,7 +760,7 @@ class Reaction:
         id: str,
         name: str,
         type: str,
-        ) -> None:
+    ) -> None:
         """
         Init Reaction model instance.
 
@@ -837,7 +781,6 @@ class Reaction:
         self.products: List[Product] = []
         self.substrates: List[Substrate] = []
 
-
     @staticmethod
     def parse(item: Element) -> "Reaction":
         """
@@ -866,7 +809,6 @@ class Reaction:
 
         return parsed_reaction
 
-
     def to_xml(self) -> Element:
         """
         Generate XML string from Reaction element.
@@ -892,10 +834,8 @@ class Reaction:
         for product in self.products:
             reaction_element.append(product.to_xml())
 
-
         return reaction_element
 
-
     def __str__(self) -> str:
         """
         Build string of reaction instance.
@@ -907,13 +847,12 @@ class Reaction:
         return f"<Reaction id='{self.id}' name='{self.name}'>"
 
 
-
-
 class Pathway:
     """
     KEGG Pathway object.
     The KEGG pathway object stores graphics information and related objects.
     """
+
     # pylint: disable=too-many-instance-attributes
 
     def __init__(
@@ -924,7 +863,7 @@ class Pathway:
         title: Optional[str] = None,
         image: Optional[str] = None,
         link: Optional[str] = None,
-        ) -> None:
+    ) -> None:
         """
         Init KEGG Pathway model.
 
@@ -936,6 +875,8 @@ class Pathway:
         :param typing.Optional[str] link: Link to pathway in KEGG database.
         """
 
+        # pylint: disable=too-many-arguments
+
         # required parameter of pathway element
         self.name: str = name
         self.org: str = org
@@ -951,12 +892,10 @@ class Pathway:
         if not is_valid_pathway_number(value=number):
             raise ValueError(f"Pathway number '{number}' is not a valid value.")
 
-
         # Check match of number, org and name
         if self.name != f"path:{self.org}{self.number}":
             raise ValueError("Mismatch of arguments name, org and number.")
 
-
         # implied
         self.title: Optional[str] = title
         self.image: Optional[str] = image
@@ -967,9 +906,6 @@ class Pathway:
         self.entries: List[Entry] = []
         self.reactions: List[Reaction] = []
 
-
-
-
     @staticmethod
     def parse(data: Union[Element, str]) -> "Pathway":
         """
@@ -983,7 +919,6 @@ class Pathway:
         # Generate correct format from string or XML element object
         item: Element = parse_xml(xml_object_or_string=data)
 
-
         # Init pathway instance with all required attributes
         pathway: Pathway = Pathway(
             name=get_attribute(element=item, key="name"),
@@ -994,7 +929,6 @@ class Pathway:
             link=item.attrib.get("link"),
         )
 
-
         # Parse child items of pathway
         for child in item:
             if child.tag == "entry":
@@ -1004,10 +938,8 @@ class Pathway:
             elif child.tag == "reaction":
                 pathway.reactions.append(Reaction.parse(child))
 
-
         return pathway
 
-
     def to_xml(self) -> Element:
         """
         Generate XML element from Pathway instance and its children.
@@ -1022,7 +954,7 @@ class Pathway:
                 "name": self.name,
                 "org": self.org,
                 "number": self.number,
-            }
+            },
         )
 
         # Adding optional attributes to pathway root element
@@ -1035,7 +967,6 @@ class Pathway:
         if self.image is not None:
             pathway_element.attrib["image"] = self.image
 
-
         # add children entries, relations and reactions
 
         for entry in self.entries:
@@ -1047,10 +978,8 @@ class Pathway:
         for reaction in self.reactions:
             pathway_element.append(reaction.to_xml())
 
-
         return pathway_element
 
-
     def to_xml_string(self) -> str:
         """
         Generate XML string from pathway instance.
@@ -1061,11 +990,14 @@ class Pathway:
 
         # Generate xml header string
         # docstring is not supported by build-in xml builer
-        xml_timestamp: str = datetime.now().astimezone().strftime("%b %d, %Y %H:%M:%S (GMT%z)")
-        xml_header: str = "<?xml version=\"1.0\"?>\n" \
-            "<!DOCTYPE pathway SYSTEM \"http://www.kegg.jp/kegg/xml/KGML_v0.7.2_.dtd\">\n" \
+        xml_timestamp: str = (
+            datetime.now().astimezone().strftime("%b %d, %Y %H:%M:%S (GMT%z)")
+        )
+        xml_header: str = (
+            '<?xml version="1.0"?>\n'
+            '<!DOCTYPE pathway SYSTEM "http://www.kegg.jp/kegg/xml/KGML_v0.7.2_.dtd">\n'
             f"<!-- Creation date: {xml_timestamp} -->\n"
-
+        )
 
         pathway_element: Element = self.to_xml()
 
@@ -1073,7 +1005,6 @@ class Pathway:
 
         return xml_header + xml_content
 
-
     def get_entry_by_id(self, entry_id: str) -> Optional[Entry]:
         """
         Get pathway Entry object by id.
@@ -1088,8 +1019,6 @@ class Pathway:
                 return item
         return None
 
-
-
     def get_genes(self) -> List[str]:
         """
         List all genes from pathway.
@@ -1113,7 +1042,6 @@ class Pathway:
                 #         if single_entry not in result:
                 #             result.append(single_entry)
 
-
                 # elif entry.name not in result:
                 #     result.append(entry.name)
 
@@ -1123,7 +1051,6 @@ class Pathway:
 
         return result
 
-
     def __str__(self) -> str:
         """
         Build string summary for KEGG pathway.
@@ -1133,22 +1060,22 @@ class Pathway:
         """
         return f"<Pathway path:{self.org}{self.number} title='{self.title}'>"
 
+    # TODO: has to be implemented
+    # def merge(self) -> "Pathway":
+    #     """
+    #     Merge identical entries in Pathway together and generate new pathway instance.
 
-    def merge(self) -> "Pathway":
-        """
-        Merge identical entries in Pathway together and generate new pathway instance.
+    #     :return: Merged Pathway instance.
+    #     :rtype: Pathway
+    #     """
 
-        :return: Merged Pathway instance.
-        :rtype: Pathway
-        """
+    #     merged_pathway: Pathway = Pathway(
+    #         name=self.name,
+    #         org=self.org,
+    #         number=self.number,
+    #         title=self.title,
+    #     )
 
-        merged_pathway: Pathway = Pathway(
-            name=self.name,
-            org=self.org,
-            number=self.number,
-            title=self.title,
-        )
+    #     # TODO find duplicate entries in pathway
 
-        # TODO find duplicate entries in pathway
-
-        return merged_pathway
+    #     return merged_pathway
